summaryrefslogtreecommitdiffstats
path: root/python/sip/sipgen/transform.c
diff options
context:
space:
mode:
Diffstat (limited to 'python/sip/sipgen/transform.c')
-rw-r--r--python/sip/sipgen/transform.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/python/sip/sipgen/transform.c b/python/sip/sipgen/transform.c
index 036a124b..d19fb719 100644
--- a/python/sip/sipgen/transform.c
+++ b/python/sip/sipgen/transform.c
@@ -111,10 +111,10 @@ void transform(sipSpec *pt)
rev = cd;
/*
* Mark any QObject class. This flag will ripple through all derived
* classes when we set the hierarchy.
*/
- if (strcmp(classBaseName(cd), "QObject") == 0)
+ if (strcmp(classBaseName(cd), "TQObject") == 0)
setIsQObjectSubClass(cd);
cd = next;
@@ -842,7 +842,7 @@ static void setHierarchy(sipSpec *pt,classDef *base,classDef *cd,
appendToMRO(cd -> mro,&tailp,mro -> cd);
/*
* If the super-class is a QObject sub-class then this one is
* as well.
*/
if (isQObjectSubClass(mro->cd))
@@ -2830,10 +2830,10 @@ static void assignClassNrs(sipSpec *pt,moduleDef *mod,nodeDef *nd)
cd -> classnr = mod -> nrclasses++;
/*
* If we find a class defined in the main module called QObject, assume
* it's Qt.
*/
- if (mod == pt -> module && strcmp(classBaseName(cd),"QObject") == 0)
+ if (mod == pt -> module && strcmp(classBaseName(cd),"TQObject") == 0)
pt -> qobjclass = cd -> classnr;
}
@@ -111,10 +111,10 @@ void transform(sipSpec *pt)
rev = cd;
/*
- * Mark any QObject class. This flag will ripple through all derived
+ * Mark any TQObject class. This flag will ripple through all derived
* classes when we set the hierarchy.
*/
@@ -842,7 +842,7 @@ static void setHierarchy(sipSpec *pt,classDef *base,classDef *cd,
appendToMRO(cd -> mro,&tailp,mro -> cd);
/*
- * If the super-class is a QObject sub-class then this one is
+ * If the super-class is a TQObject sub-class then this one is
* as well.
*/
@@ -2830,10 +2830,10 @@ static void assignClassNrs(sipSpec *pt,moduleDef *mod,nodeDef *nd)
cd -> classnr = mod -> nrclasses++;
/*
- * If we find a class defined in the main module called QObject, assume
+ * If we find a class defined in the main module called TQObject, assume
* it's Qt.
*/